@@ -4,51 +4,25 @@ package Test::Class::Moose::Report::Time;
 
 use 5.10.0;
 
-our $VERSION = '0.65';
+our $VERSION = '0.66';
 
 use Moose;
 use Benchmark qw(timestr :hireswallclock);
+use List::Util qw( max );
 use namespace::autoclean;
 
-has 'real' => (
-    is       => 'ro',
-    isa      => 'Num',
-    lazy     => 1,
-    default  => sub { $_[0]->_timediff->[0] },
-    init_arg => undef,
-);
-
-has 'user' => (
-    is       => 'ro',
-    isa      => 'Num',
-    lazy     => 1,
-    default  => sub { $_[0]->_timediff->[1] },
-    init_arg => undef,
-);
-
-has 'system' => (
-    is       => 'ro',
-    isa      => 'Num',
-    lazy     => 1,
-    default  => sub { $_[0]->_timediff->[2] },
-    init_arg => undef,
-);
-
-has '_children_user' => (
-    is       => 'ro',
-    isa      => 'Num',
-    lazy     => 1,
-    default  => sub { $_[0]->_timediff->[3] },
-    init_arg => undef,
-);
-
-has '_children_system' => (
-    is       => 'ro',
-    isa      => 'Num',
-    lazy     => 1,
-    default  => sub { $_[0]->_timediff->[4] },
-    init_arg => undef,
-);
+{
+    my @fields = qw( real user system _children_user _children_system );
+    for my $i ( 0 .. $#fields ) {
+        has $fields[$i] => (
+            is       => 'ro',
+            isa      => 'Num',
+            lazy     => 1,
+            default  => sub { max( $_[0]->_timediff->[$i], 0 ) },
+            init_arg => undef,
+        );
+    }
+}
 
 has '_iters' => (
     is       => 'ro',
@@ -89,7 +63,7 @@ Test::Class::Moose::Report::Time - Reporting object for timing
 
 =head1 VERSION
 
-version 0.65
+version 0.66
 
 =head1 DESCRIPTION
 
